@@ -1,6 +1,6 @@
 """Some helper functions and classes that I want in nearly every project."""
 
-__version__ = "0.1.1"
+__version__ = "0.1.4"
 
 import enum
 import sys
@@ -76,11 +76,26 @@ class SumType(enum.Enum):
 def get(s: Set[T]) -> T:
     """
     Returns a arbitrary (first) element of s
+
+    :param s: Set of elements
+    :type s: Set[T]
+    :return: an element of s.
+    :rtype: T
     """
     return next(iter(s))
 
 
-def argsort(lst: Sequence[T], reverse: bool = False) -> List[int]:
+def argsort(lst: Sequence[object], reverse: bool = False) -> List[int]:
+    """
+    Returns the sorted indices of the list.
+
+    :param lst: Sequence (list or list sub-class) of elements.
+    :type lst: Sequence[object]
+    :param reverse: Optional argument, whether to reverse the order of the sort.
+    :rtype reverse: bool
+    :return: A list of indices for lst, sorted by the values in lst
+    :rtype: List[int]
+    """
     return [i for e, i in sorted(((e, i) for i, e in enumerate(lst)), reverse=reverse)]
 
 
@@ -88,24 +103,44 @@ def flattened(nested_list: List[List[T]]) -> List[T]:
     """
     Takes a list of lists and returns a flattened list
 
-    Check list(itertools.chain(*regular_list)) for performance
+
+    :param nested_list: A list of lists
+    :type nested_list: List[List[T]]
+    :returns: A single, flat list of elements.
+    :rtype: List[T]
     """
+
+    # TODO: Compare against list(itertools.chain(*regular_list)) for performance
+
     return [item for sublist in nested_list for item in sublist]
 
 
 def indexed(lst: Sequence[T], indices: Iterable[int]) -> List[T]:
+    """
+    Indexes into a list with multiple indices.
+
+    >>> indexed([6, 7, 8, 9, 10], [0, 3])
+    [6, 9]
+
+    :param lst: Any generic indexable type to index
+    :type lst: Sequence[T]
+    :param indices: An iterable of indices (could be ints, keys)
+    :type indices: Iterable[int]
+    :returns: A list of the indexed values
+    :rtype: List[T]
+    """
     result = []
     for i in indices:
         result.append(lst[i])
     return result
 
 
-def grouped(things: Sequence[T], size: int = 1) -> Iterator[Tuple[T, ...]]:
+def grouped(things: Sequence[T], *, size: int = 1) -> Iterator[Tuple[T, ...]]:
     """
     Produces a sliding window over 'things'.
 
-    Example:
-        grouped([1, 2, 3, 4], 2) == [(1, 2), (2, 3), (3, 4)]
+    >>> grouped([1, 2, 3, 4], size=2)
+    [(1, 2), (2, 3), (3, 4)]
     """
     rows = [things[i:] for i in range(size)]
 
@@ -126,6 +161,8 @@ def never(value: NoReturn) -> NoReturn:
 def eprint(*args, **kwargs):  # type: ignore
     """
     Print to stderr.
+
+    All arguments are passed straight through to print.
     """
     print(*args, file=sys.stderr, **kwargs)
 
