@@ -1,4 +1,4 @@
-from preface import dict
+import preface
 
 
 def test_set_dict_without_nested_dict() -> None:
@@ -9,7 +9,7 @@ def test_set_dict_without_nested_dict() -> None:
     value = 1
 
     expected = {"a": {"b": {"c": 1}}}
-    dict.set(dct, key, value)
+    preface.dict.set(dct, key, value)
 
     assert dct == expected
 
@@ -19,7 +19,7 @@ def test_merge_dict_without_nested() -> None:
     b = {"b": 2}
 
     expected = {"a": 1, "b": 2}
-    actual = dict.merge(a, b)
+    actual = preface.dict.merge(a, b)
 
     assert actual == expected
 
@@ -29,6 +29,18 @@ def test_merge_dict_with_nested():
     b = {"b": 2, "a": {"c": 3}}
 
     expected = {"a": {"b": 1, "c": 3}, "b": 2}
-    actual = dict.merge(a, b)
+    actual = preface.dict.merge(a, b)
 
     assert actual == expected
+
+
+def test_pop_dict_with_nested_dict() -> None:
+    dct = {"a": {"b": 1}}
+
+    expected_value = 1
+    expected_dct = {"a": {}}
+
+    actual_value = preface.dict.pop(dct, "a.b")
+
+    assert actual_value == expected_value
+    assert dct == expected_dct
